Wordle
========

A suite of tools to build, test and run algorithms that solve the popular web-game 'Wordle'

Installation
------------

```bash
pip install -r requirements.txt
pip install -e
```

To run existing bots:

```bash
python -m pytest -s
```

License
-------

This project is licensed under the GNU GENERAL PUBLIC LICENSE Version 3
